# Ansible Risk Insight Documentation

## About Ansible Risk Insight

Ansible Risk Insight (ARI) is a command-line tool for assessing quality and potential risks of the Ansible content of playbooks, roles, and collections. ARI understands the taxonomy of Ansible data structures and content types and do context analysis on task call tree across dependencies and variable tracking in static-analytics fashion. ARI can be extensible with customizable rules. 

